pub struct CompiledContract { /* private fields */ }Expand description
Contract execution IR compiled in Arrow schema order.
Implementations
Sourceimpl CompiledContract
impl CompiledContract
Sourcepub fn compile(
contract: &ContractAst,
schema: &Schema,
) -> Result<Self, ProofFrameError>
pub fn compile( contract: &ContractAst, schema: &Schema, ) -> Result<Self, ProofFrameError>
Resolve and type-check a syntax tree before any record batch is scanned.
Sourcepub fn compile_document(
document: &ContractDocument,
schema: &Schema,
) -> Result<Self, ProofFrameError>
pub fn compile_document( document: &ContractDocument, schema: &Schema, ) -> Result<Self, ProofFrameError>
Compile either frozen V1 syntax or the relational V2 contract language.
pub fn columns(&self) -> &[ColumnPlan]
pub const fn schema(&self) -> &Schema
pub fn row_plans(&self) -> &[RowPlan]
pub const fn dataset_plan(&self) -> &DatasetPlan
pub const fn max_findings(&self) -> usize
Sourcepub fn schema_digest(&self) -> Result<String, ProofFrameError>
pub fn schema_digest(&self) -> Result<String, ProofFrameError>
Domain-separated digest of the Arrow schema used during compilation.
Sourcepub fn compiled_plan_digest(&self) -> Result<String, ProofFrameError>
pub fn compiled_plan_digest(&self) -> Result<String, ProofFrameError>
Domain-separated digest of the schema-resolved execution plan.